mutationtools.AttributeInspectionAgent
======================================

.. abjad-lineage:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent

.. autoclass:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_annotation
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_badly_formed_components
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_components
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_contents
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_descendants
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_duration
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_effective_context_mark
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_effective_staff
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_grace_containers
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_leaf
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_lineage
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_mark
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_marks
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_markup
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_parentage
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_spanner
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_spanners
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_tie_chain
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_timespan
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_vertical_moment
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_vertical_moment_at
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.is_bar_line_crossing
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.is_well_formed
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.report_modifications
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.tabulate_well_formedness_violations
      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.__repr__

Bases
-----

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_annotation
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_badly_formed_components
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_components
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_contents
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_descendants
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_duration
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_effective_context_mark
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_effective_staff
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_grace_containers
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_leaf
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_lineage
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_mark
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_marks
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_markup
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_parentage
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_spanner
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_spanners
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_tie_chain
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_timespan
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_vertical_moment
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.get_vertical_moment_at
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.is_bar_line_crossing
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.is_well_formed
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.report_modifications
   :noindex:

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.tabulate_well_formedness_violations
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent.__repr__
   :noindex:
